@@ -5,6 +5,8 @@ from functools import wraps
 from dateutil.parser import parse as parse_date
 import re
 
+ESCAPE = '"'
+
 class color():
     black = lambda x: '\033[30m' + str(x)+'\033[0;39m'
     red = lambda x: '\033[31m' + str(x)+'\033[0;39m'
@@ -126,7 +128,7 @@ class MetaTable(type):
     def __call__(cls, field):
         if field not in cls.fields:
             raise UnknownField(field)
-        return '"'+cls.name+'"."'+(field if not 'field' in cls.fields[field] else cls.fields[field]['field'])+'"'
+        return ESCAPE+cls.name+ESCAPE+'.'+ESCAPE+(field if not 'field' in cls.fields[field] else cls.fields[field]['field'])+ESCAPE
 
 class Table(metaclass=MetaTable):
     type = lambda x: None
@@ -142,8 +144,8 @@ class Table(metaclass=MetaTable):
     def str(cls):
         result = ''
         if cls.schema:
-            result += '"'+cls.schema+'".'
-        return result + '"'+cls.name+'"'
+            result += ESCAPE+cls.schema+ESCAPE+'.'
+        return result + ESCAPE+cls.name+ESCAPE
     """
         Returns an array for updating table
         update['fields'] = 'field1=%s, field2=%s'
@@ -191,21 +193,16 @@ class Table(metaclass=MetaTable):
                     config['type'] = 'string'
 
                 if 'array' in config and config['array']:
-                    criteria = '%s = ANY('+cls.name+'."'+column+'")'
+                    criteria = '%s = ANY('+cls.name+'.'+ESCAPE+column+ESCAPE+')'
                 elif config['type'] == 'json':
-                    #repeat = '"% '+value+'%"'
-                    #value = '%: "%'+value+'%"%'
                     value = '%'+value+'%'
-                    #criteria = "("+cls.name+'."'+column+"\"::text LIKE %s OR "+cls.name+'."'+column+"\"::text LIKE %s)"
-                    criteria = cls.name+'."'+column+"\"::text ILIKE %s"
+                    criteria = cls.name+'.'+ESCAPE+column+ESCAPE+'::text ILIKE %s'
                 elif 'options' in config or config['type'] == 'bool':
-                    criteria = cls.name+'."'+column+'"=%s'
+                    criteria = cls.name+'.'+ESCAPE+column+ESCAPE+'=%s'
                 elif config['type'] == 'int' or config['type'] == 'date' or config['type'] == 'float':
-                    criteria = cls.name+'."'+column+'"=%s'
+                    criteria = cls.name+'.'+ESCAPE+column+ESCAPE+'=%s'
                 else:
-                    #repeat = '% '+value+'%'
                     value = '%'+value+'%'
-                    #criteria = "("+cls.name+'."'+column+"\" LIKE %s OR "+cls.name+'."'+column+"\" LIKE %s)"
                     criteria = cls.name+'."'+column+"\" ILIKE %s"
 
                 if 'array' in config and config['array']:
@@ -283,7 +280,7 @@ class Table(metaclass=MetaTable):
         if 'type' not in config:
             config['type'] = 'string'
 
-        column = cls.name+'."'+(config['field'] if 'field' in config else field)+'"'
+        column = cls.name+'.'+ESCAPE+(config['field'] if 'field' in config else field)+ESCAPE
 
         if config['type'] == 'json':
             if 'key' is None:
@@ -431,6 +428,8 @@ class Table(metaclass=MetaTable):
                     params[field] = config['decoder'](data[position])
                 else:
                     params[field] = data[position]
+                    if 'type' in config and config['type'] == 'json' and isinstance(params[field], str):
+                        params[field] = json.loads(params[field])
             position += 1
         #print(params)
         # if cls.name=='user_media':print(color.magenta(cls.type.__name__))
@@ -458,7 +457,7 @@ class Table(metaclass=MetaTable):
             cursor.execute(f"""SELECT {join.select()}
                              FROM {cls}
                              {join}
-                             WHERE {cls('id')}=%s""",
+                             WHERE {cls(cls.id)}=%s""",
                              (id,))
             join.row.data(cursor.fetchone())
             result = join.create()
@@ -483,7 +482,7 @@ class Table(metaclass=MetaTable):
                            FROM {cls}
                            {join}
                            WHERE {join.fields()}
-                           ORDER BY {cls.order('id', 'desc', order)}
+                           ORDER BY {cls.order(cls.id, 'desc', order)}
                            {f'LIMIT {int(limit)}' if limit else ''}""",
                            join.values()))
             log.debug(color.cyan('Total fetched %s'), cursor.rowcount)
@@ -523,7 +522,7 @@ class Table(metaclass=MetaTable):
                            FROM {cls}
                            {join}
                            WHERE {join.fields()}
-                           ORDER BY {join.order('id', 'desc', order)}
+                           ORDER BY {join.order(cls.id, 'desc', order)}
                            LIMIT %s OFFSET %s""",
                            join.values()+[limit, offset]))
             log.debug(color.cyan('Total fetched %s'), cursor.rowcount)
@@ -558,7 +557,7 @@ class Table(metaclass=MetaTable):
             cursor.execute(*debug(f"""WITH "{cls.name}" AS (
                                         UPDATE {cls}
                                         SET {update.fields()}
-                                        WHERE {cls('id')}=%s AND {filter.fields()}
+                                        WHERE {cls(cls.id)}=%s AND {filter.fields()}
                                         RETURNING {cls.select()}
                                     )
                                     SELECT {join.select()}
@@ -621,7 +620,7 @@ class Table(metaclass=MetaTable):
             db = cls.get_db()
             cursor = db.cursor()
             cursor.execute(*debug(f"""DELETE FROM {cls}
-                                    WHERE {cls('id')}=%s AND {filter.fields()}""",
+                                    WHERE {cls(cls.id)}=%s AND {filter.fields()}""",
                                 (id,)+filter.values()))
             return bool(cursor.rowcount)
         except Exception as error:
